@@ -143,7 +143,7 @@ PyObject *sip_api_invoke_slot(const sipSlot *slot, PyObject *sigargs)
          * longer exists.
          */
         if (PyObject_TypeCheck(self, (PyTypeObject *)&sipSimpleWrapper_Type) &&
-            sip_api_get_address(self) == NULL)
+            sip_api_get_address((sipSimpleWrapper *)self) == NULL)
         {
             Py_XDECREF(sref);
 
@@ -569,7 +569,7 @@ int sip_api_save_slot(sipSlot *sp, PyObject *rxObj, const char *slot)
                  * because they are generated on the fly and we can't take a
                  * reference as that may keep the instance (ie. self) alive.
                  * We therefore treat it as if the user had specified the slot
-                 * at "obj, TQT_SLOT('meth()')" rather than "obj.meth" (see below).
+                 * at "obj, TQ_SLOT('meth()')" rather than "obj.meth" (see below).
                  */
 
                 const char *meth;
@@ -610,7 +610,7 @@ int sip_api_save_slot(sipSlot *sp, PyObject *rxObj, const char *slot)
     {
         /*
          * The user has decided to connect a Python signal to a TQt slot and
-         * specified the slot as "obj, TQT_SLOT('meth()')" rather than "obj.meth".
+         * specified the slot as "obj, TQ_SLOT('meth()')" rather than "obj.meth".
          */
 
         char *tail;
